﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/ec2/EC2_EXPORTS.h>

namespace Aws {
namespace EC2 {
namespace Model {
enum class InstanceLifecycleType { NOT_SET, spot, scheduled, capacity_block };

namespace InstanceLifecycleTypeMapper {
AWS_EC2_API InstanceLifecycleType GetInstanceLifecycleTypeForName(const Aws::String& name);

AWS_EC2_API Aws::String GetNameForInstanceLifecycleType(InstanceLifecycleType value);
}  // namespace InstanceLifecycleTypeMapper
}  // namespace Model
}  // namespace EC2
}  // namespace Aws
